using System;
using System.IO;
using System.Data;
using System.Data.SqlClient;
using System.Collections;

using Altiris.Common;
using Altiris.NS;
using Altiris.NS.ContextManagement;
using Altiris.NS.ItemManagement;
using Altiris.NS.Security;
using Altiris.NS.Logging;

class DeleteItems
{

   #region Internal SQL

   static public string sql = @"select [Guid] from vComputer where IsManaged = '0'";

   #endregion

   #region Helper Methods

   //
   // Method takes a SQL query as parameter 
   // and performs Item.Delete on the resulting guids
   //
   static public int DeleteSQLResults(string sql)
   {
      ArrayList arrResults = new ArrayList();
      using (DatabaseContext context = DatabaseContext.GetContext())
      {
         SqlCommand command = (SqlCommand)context.CreateCommand(sql);

         using (SqlDataReader reader = command.ExecuteReader())
         {
            while (reader.Read())
            {
               arrResults.Add(reader.GetGuid(0));
            }
         }
      }

      int count = 0;

      Console.Write("\tDeleting " + arrResults.Count + " items.");

      foreach (Guid guid in arrResults)
      {

         Item i = Item.GetItem(guid) as Item;
         if (i != null)
         {
            try
            {
               if (!i.CanDelete())
               {
                  i.ItemAttributes = ItemAttributes.Normal;
                  i.Save();
               }

               Item.DeleteItem(i.Guid);
               count++;

               if (count % 50 == 0)
                  Console.Write(".");
            }
            catch (Exception ex)
            {
               Altiris.NS.Logging.EventLog.ReportError("Error deleting " + i.Name);
               Altiris.NS.Logging.EventLog.ReportError(ex.Message);
               Altiris.NS.Logging.EventLog.ReportError(ex.StackTrace);
            }
         }
      }
      return (count);
   }

   #endregion

   static void Main(string[] args)
   {
      //
      //	Set the security context for the current user
      //
      SecurityContextManager.SetContextData();

      int count;

      Console.WriteLine("Deleting Items...");
      count = DeleteSQLResults(sql);
      Console.WriteLine("\n" + count + " deleted");
   }

}